==> pmml-model-gwt-1.1.14.jar: org/dmg/pmml/Level.java <==

package org.dmg.pmml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jpmml.schema.Added;
import org.jpmml.schema.Removed;
import org.jpmml.schema.Version;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="alpha" type="{http://www.dmg.org/PMML-4_2}REAL-NUMBER" />
 *       &lt;attribute name="quadraticSmoothedValue" type="{http://www.dmg.org/PMML-4_2}REAL-NUMBER" />
 *       &lt;attribute name="cubicSmoothedValue" type="{http://www.dmg.org/PMML-4_2}REAL-NUMBER" />
 *       &lt;attribute name="smoothedValue" type="{http://www.dmg.org/PMML-4_2}REAL-NUMBER" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "Level", namespace = "http://www.dmg.org/PMML-4_2")
@Added(Version.PMML_4_0)
public class Level
    extends PMMLObject
{

    @XmlAttribute(name = "alpha")
    protected Double alpha;
    @XmlAttribute(name = "quadraticSmoothedValue")
    @Removed(Version.PMML_4_1)
    protected Double quadraticSmoothedValue;
    @XmlAttribute(name = "cubicSmoothedValue")
    @Removed(Version.PMML_4_1)
    protected Double cubicSmoothedValue;
    @XmlAttribute(name = "smoothedValue")
    protected Double smoothedValue;

    /**
     * Gets the value of the alpha property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getAlpha() {
        return alpha;
    }

    /**
     * Sets the value of the alpha property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setAlpha(Double value) {
        this.alpha = value;
    }

    /**
     * Gets the value of the quadraticSmoothedValue property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getQuadraticSmoothedValue() {
        return quadraticSmoothedValue;
    }

    /**
     * Sets the value of the quadraticSmoothedValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setQuadraticSmoothedValue(Double value) {
        this.quadraticSmoothedValue = value;
    }

    /**
     * Gets the value of the cubicSmoothedValue property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getCubicSmoothedValue() {
        return cubicSmoothedValue;
    }

    /**
     * Sets the value of the cubicSmoothedValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setCubicSmoothedValue(Double value) {
        this.cubicSmoothedValue = value;
    }

    /**
     * Gets the value of the smoothedValue property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getSmoothedValue() {
        return smoothedValue;
    }

    /**
     * Sets the value of the smoothedValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setSmoothedValue(Double value) {
        this.smoothedValue = value;
    }

    public Level withAlpha(Double value) {
        setAlpha(value);
        return this;
    }

    public Level withQuadraticSmoothedValue(Double value) {
        setQuadraticSmoothedValue(value);
        return this;
    }

    public Level withCubicSmoothedValue(Double value) {
        setCubicSmoothedValue(value);
        return this;
    }

    public Level withSmoothedValue(Double value) {
        setSmoothedValue(value);
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        visitor.pushParent(this);
        visitor.popParent();
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.2.3.jar: org/dmg/pmml/Level.java <==

package org.dmg.pmml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jpmml.schema.Added;
import org.jpmml.schema.Removed;
import org.jpmml.schema.Version;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="alpha" type="{http://www.dmg.org/PMML-4_2}REAL-NUMBER" />
 *       &lt;attribute name="quadraticSmoothedValue" type="{http://www.dmg.org/PMML-4_2}REAL-NUMBER" />
 *       &lt;attribute name="cubicSmoothedValue" type="{http://www.dmg.org/PMML-4_2}REAL-NUMBER" />
 *       &lt;attribute name="smoothedValue" type="{http://www.dmg.org/PMML-4_2}REAL-NUMBER" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "Level", namespace = "http://www.dmg.org/PMML-4_2")
@Added(Version.PMML_4_0)
public class Level
    extends PMMLObject
{

    @XmlAttribute(name = "alpha")
    private Double alpha;
    @XmlAttribute(name = "quadraticSmoothedValue")
    @Removed(Version.PMML_4_1)
    private Double quadraticSmoothedValue;
    @XmlAttribute(name = "cubicSmoothedValue")
    @Removed(Version.PMML_4_1)
    private Double cubicSmoothedValue;
    @XmlAttribute(name = "smoothedValue")
    private Double smoothedValue;

    /**
     * Gets the value of the alpha property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getAlpha() {
        return alpha;
    }

    /**
     * Sets the value of the alpha property.
     * 
     * @param alpha
     *     allowed object is
     *     {@link Double }
     *     
     */
    public Level setAlpha(Double alpha) {
        this.alpha = alpha;
        return this;
    }

    /**
     * Gets the value of the quadraticSmoothedValue property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getQuadraticSmoothedValue() {
        return quadraticSmoothedValue;
    }

    /**
     * Sets the value of the quadraticSmoothedValue property.
     * 
     * @param quadraticSmoothedValue
     *     allowed object is
     *     {@link Double }
     *     
     */
    public Level setQuadraticSmoothedValue(Double quadraticSmoothedValue) {
        this.quadraticSmoothedValue = quadraticSmoothedValue;
        return this;
    }

    /**
     * Gets the value of the cubicSmoothedValue property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getCubicSmoothedValue() {
        return cubicSmoothedValue;
    }

    /**
     * Sets the value of the cubicSmoothedValue property.
     * 
     * @param cubicSmoothedValue
     *     allowed object is
     *     {@link Double }
     *     
     */
    public Level setCubicSmoothedValue(Double cubicSmoothedValue) {
        this.cubicSmoothedValue = cubicSmoothedValue;
        return this;
    }

    /**
     * Gets the value of the smoothedValue property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getSmoothedValue() {
        return smoothedValue;
    }

    /**
     * Sets the value of the smoothedValue property.
     * 
     * @param smoothedValue
     *     allowed object is
     *     {@link Double }
     *     
     */
    public Level setSmoothedValue(Double smoothedValue) {
        this.smoothedValue = smoothedValue;
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        visitor.pushParent(this);
        visitor.popParent();
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
